@@ -1,20 +1,17 @@
 #' Get user IDs for accounts following target user.
 #'
 #' Returns a list of user IDs for the accounts following specified
-#' user.
+#' user. `r lifecycle::badge("deprecated")`
 #'
 #' @inheritParams TWIT_paginate_cursor
 #' @inheritParams get_timeline
+#' @inheritParams stream
 #' @param page `r lifecycle::badge("deprecated")` Please use `cursor` instead.
+#' @seealso [`rtweet-deprecated`]
 #' @references <https://developer.twitter.com/en/docs/twitter-api/v1/accounts-and-users/follow-search-get-users/api-reference/get-followers-ids>
 #' @examples
-#' if (auth_has_default()) {
+#' if (FALSE) {
 #'   users <- get_followers("_R_Foundation")
-#'   users
-#'
-#'   # use `cursor` to find the next "page" of results
-#'   more_users <- get_followers("_R_Foundation", cursor = users)
-#'
 #' }
 #' @return A tibble data frame with one column named "from_id" with the
 #' followers and another one "to_id" with the user used as input.
@@ -32,7 +29,7 @@ get_followers <- function(user, n = 5000,
     cursor <- page
   }
 
-  stopifnot(is.atomic(user), isTRUE(length(user) == 1))
+  stopifnot(is.atomic(user) && !is.null(user), isTRUE(length(user) == 1))
 
   params <- list(stringify_ids = TRUE)
   params[[user_type(user)]] <- user
